==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/sagemaker/EndpointConfigReference.java <==
package software.amazon.awscdk.interfaces.sagemaker;

/**
 * A reference to a EndpointConfig resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.sagemaker.*;
 * EndpointConfigReference endpointConfigReference = EndpointConfigReference.builder()
 *         .endpointConfigId("endpointConfigId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.913Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_sagemaker.EndpointConfigReference")
@software.amazon.jsii.Jsii.Proxy(EndpointConfigReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EndpointConfigReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the EndpointConfig resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEndpointConfigId();

    /**
     * @return a {@link Builder} of {@link EndpointConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EndpointConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EndpointConfigReference> {
        java.lang.String endpointConfigId;

        /**
         * Sets the value of {@link EndpointConfigReference#getEndpointConfigId}
         * @param endpointConfigId The Id of the EndpointConfig resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder endpointConfigId(java.lang.String endpointConfigId) {
            this.endpointConfigId = endpointConfigId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EndpointConfigReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EndpointConfigReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EndpointConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EndpointConfigReference {
        private final java.lang.String endpointConfigId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.endpointConfigId = software.amazon.jsii.Kernel.get(this, "endpointConfigId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.endpointConfigId = java.util.Objects.requireNonNull(builder.endpointConfigId, "endpointConfigId is required");
        }

        @Override
        public final java.lang.String getEndpointConfigId() {
            return this.endpointConfigId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("endpointConfigId", om.valueToTree(this.getEndpointConfigId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_sagemaker.EndpointConfigReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EndpointConfigReference.Jsii$Proxy that = (EndpointConfigReference.Jsii$Proxy) o;

            return this.endpointConfigId.equals(that.endpointConfigId);
        }

        @Override
        public final int hashCode() {
            int result = this.endpointConfigId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/sagemaker/EndpointConfigReference.java <==
package software.amazon.awscdk.interfaces.sagemaker;

/**
 * A reference to a EndpointConfig resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.sagemaker.*;
 * EndpointConfigReference endpointConfigReference = EndpointConfigReference.builder()
 *         .endpointConfigId("endpointConfigId")
 *         .endpointConfigName("endpointConfigName")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.125Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_sagemaker.EndpointConfigReference")
@software.amazon.jsii.Jsii.Proxy(EndpointConfigReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EndpointConfigReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the EndpointConfig resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEndpointConfigId();

    /**
     * The EndpointConfigName of the EndpointConfig resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEndpointConfigName();

    /**
     * @return a {@link Builder} of {@link EndpointConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EndpointConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EndpointConfigReference> {
        java.lang.String endpointConfigId;
        java.lang.String endpointConfigName;

        /**
         * Sets the value of {@link EndpointConfigReference#getEndpointConfigId}
         * @param endpointConfigId The Id of the EndpointConfig resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder endpointConfigId(java.lang.String endpointConfigId) {
            this.endpointConfigId = endpointConfigId;
            return this;
        }

        /**
         * Sets the value of {@link EndpointConfigReference#getEndpointConfigName}
         * @param endpointConfigName The EndpointConfigName of the EndpointConfig resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder endpointConfigName(java.lang.String endpointConfigName) {
            this.endpointConfigName = endpointConfigName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EndpointConfigReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EndpointConfigReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EndpointConfigReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EndpointConfigReference {
        private final java.lang.String endpointConfigId;
        private final java.lang.String endpointConfigName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.endpointConfigId = software.amazon.jsii.Kernel.get(this, "endpointConfigId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.endpointConfigName = software.amazon.jsii.Kernel.get(this, "endpointConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.endpointConfigId = java.util.Objects.requireNonNull(builder.endpointConfigId, "endpointConfigId is required");
            this.endpointConfigName = java.util.Objects.requireNonNull(builder.endpointConfigName, "endpointConfigName is required");
        }

        @Override
        public final java.lang.String getEndpointConfigId() {
            return this.endpointConfigId;
        }

        @Override
        public final java.lang.String getEndpointConfigName() {
            return this.endpointConfigName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("endpointConfigId", om.valueToTree(this.getEndpointConfigId()));
            data.set("endpointConfigName", om.valueToTree(this.getEndpointConfigName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_sagemaker.EndpointConfigReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EndpointConfigReference.Jsii$Proxy that = (EndpointConfigReference.Jsii$Proxy) o;

            if (!endpointConfigId.equals(that.endpointConfigId)) return false;
            return this.endpointConfigName.equals(that.endpointConfigName);
        }

        @Override
        public final int hashCode() {
            int result = this.endpointConfigId.hashCode();
            result = 31 * result + (this.endpointConfigName.hashCode());
            return result;
        }
    }
}
